@@ -100,7 +100,7 @@ gboolean VideoWidget::busCallback_callback (GstBus * bus, GstMessage * message)
 // End listing callback functions
 void VideoWidget::start() {
     gst_x_overlay_set_xwindow_id(GST_X_OVERLAY(data), this->winId());
-    g_object_set(G_OBJECT(input_selector), "active-pad", gst_element_get_pad(video_crop, "src"), NULL);
+//    g_object_set(G_OBJECT(input_selector), "active-pad", gst_element_get_pad(video_crop, "src"), NULL);
     gst_element_set_state(pipeline, GST_STATE_PLAYING);
     gst_photography_set_scene_mode (GST_PHOTOGRAPHY (camera_src), GST_PHOTOGRAPHY_SCENE_MODE_CLOSEUP); // uncommented to fix focus although we are using crop
     refocus();
@@ -151,9 +151,9 @@ bool VideoWidget::initPipeline() {
 
 
     file_src = gst_element_factory_make("filesrc", "file_src");
-
+    //useFilesrc("/usr/share/icons/hicolor/14x14/hildon/general_alarm_on.png"); // dummy file to do a quickfix
     input_selector = gst_element_factory_make("input-selector", "input_selector");
-    g_object_set(G_OBJECT(input_selector), "n-pads", 2, NULL); // set 2 input pads
+//    g_object_set(G_OBJECT(input_selector), "n-pads", 2, NULL); // set 2 input pads
 
 
     /* Colorspace filter is needed to make sure that sinks understands
@@ -210,7 +210,7 @@ bool VideoWidget::initPipeline() {
     g_object_set (G_OBJECT (image_sink), "sync", FALSE, NULL);
 
     /* Check that elements are correctly initialized */
-    if (!(pipeline && camera_src && screen_sink && csp_filter && screen_queue && image_queue && image_sink && video_crop && file_src && input_selector)) {
+    if (!(pipeline && camera_src && screen_sink && csp_filter && screen_queue && image_queue && image_sink && video_crop /*&& file_src && input_selector*/)) {
         g_critical ("Couldn't create pipeline elements");
         return FALSE;
     }
@@ -221,7 +221,7 @@ bool VideoWidget::initPipeline() {
 
     /* Add elements to the pipeline. This has to be done prior to
      * linking them */
-    gst_bin_add_many (GST_BIN (pipeline), camera_src, file_src, csp_filter, video_crop, input_selector, tee, screen_queue, screen_sink, image_queue, image_sink, NULL);
+    gst_bin_add_many (GST_BIN (pipeline), camera_src, /*file_src,*/ csp_filter, video_crop, /*input_selector,*/ tee, screen_queue, screen_sink, image_queue, image_sink, NULL);
 
     /* Specify what kind of video is wanted from the camera */
     if (deviceType==DEVICE_N900){
@@ -248,17 +248,18 @@ bool VideoWidget::initPipeline() {
 
     /* Connect Colorspace Filter -> Tee -> Screen Queue -> Screen Sink
      * This finalizes the initialization of the screen-part of the pipeline */
-    if (!gst_element_link(csp_filter, video_crop))
-        return FALSE;
+//    if (!gst_element_link(csp_filter, video_crop))
+//        return FALSE;
 
 
     // link up the input_selector here
-    gst_element_link_pads (video_crop, "src", input_selector, "sink");
-    gst_element_link_pads (file_src, "src", input_selector, "sink");
+//    gst_element_link_pads (video_crop, "src", input_selector, "sink");
+//    gst_element_link_pads (file_src, "src", input_selector, "sink");
 
     //g_object_set(G_OBJECT(input_selector), "active-pad", gst_element_get_pad(video_crop, "src"), NULL);
 
-    if (!gst_element_link_many (input_selector, tee, screen_queue, screen_sink, NULL))
+//    if (!gst_element_link_many (input_selector, tee, screen_queue, screen_sink, NULL))
+    if (!gst_element_link_many (csp_filter, video_crop, tee, screen_queue, screen_sink, NULL))
         return FALSE;
 
 
@@ -520,10 +521,10 @@ bool VideoWidget::isFocusing() {
 }
 
 void VideoWidget::useVideosrc() {
-    g_object_set(G_OBJECT(input_selector), "active-pad", gst_element_get_pad(video_crop, "src"), NULL); // make video_crop the source
+//    g_object_set(G_OBJECT(input_selector), "active-pad", gst_element_get_pad(video_crop, "src"), NULL); // make video_crop the source
 }
 
 void VideoWidget::useFilesrc(QString filename) {
-    g_object_set(G_OBJECT(input_selector), "active-pad", gst_element_get_pad(file_src, "src"), NULL); // make filesrc the source
-    g_object_set(G_OBJECT(file_src), "location", filename.toAscii(), NULL); // set the location
+//    g_object_set(G_OBJECT(input_selector), "active-pad", gst_element_get_pad(file_src, "src"), NULL); // make filesrc the source
+//    g_object_set(G_OBJECT(file_src), "location", filename.toAscii(), NULL); // set the location
 }
